texlive: A comprehensive TeX system
===================================

Description
-----------

TeX Live is an easy way to get up and running with the TeX document
production system. It provides a comprehensive TeX system with binaries
for most flavors of Unix, including GNU/Linux, and also Windows. It
includes all the major TeX-related programs, macro packages, and fonts
that are free software, including support for many languages around the
world.

This package installs all texlive packages required to build Sage. If
necessary, texlive itself is installed.

License
-------

Various FSF-approved free software licenses. See
https://www.tug.org/texlive/copying.html for details.


Upstream Contact
----------------

Home page: https://www.tug.org/texlive

Dependencies
------------

-  python


Special Update/Build Instructions
---------------------------------

This package requires internet access to download texlive packages for
the TeX mirrors.
